# Turf Analysis
# Auhor: Mladen Jovanovic
# Date: June, 2017
# Email: coach.mladen.jovanovic@gmail.com

# Load libraries
library(dplyr)
library(ggplot2)
library(caret)

# Load data
turfData <- read.csv(file = "Turf Data.csv",
                     header = TRUE,
                     stringsAsFactors = TRUE)

# Select columns
turfData <- turfData %>%
            select(Day, Athlete, Morning.Soreness, Field, Training.Load)

# Normalize the Training.Load and Morning.Soreness per athlete
normalize <- function(x){
    round((x-min(x, na.rm = TRUE))/(max(x, na.rm = TRUE)-min(x, na.rm = TRUE)), 2)
}

turfData <- turfData %>%
            group_by(Athlete) %>%
            mutate(Morning.Soreness = normalize(Morning.Soreness),
                   Training.Load = normalize(Training.Load)) %>%
            ungroup()

# Plot the data
gg <- ggplot(turfData, aes(x = Day)) +
      geom_bar(aes(y = Training.Load), stat="identity", alpha = 0.5) +
      geom_line(aes(y = Morning.Soreness), color = "blue") + 
      facet_wrap(~Athlete) +
      theme_bw()
gg

# Create new variables (Time lag)
turfData <- turfData %>%
            group_by(Athlete) %>%
            arrange(Day) %>%
            # Field variable
            mutate(Field.Lag1 = lag(Field, 1),
                   Field.Lag2 = lag(Field, 2),
                   Field.Lag3 = lag(Field, 3),
                   Field.Lag4 = lag(Field, 4),
                   Field.Lag5 = lag(Field, 5)) %>%
            # Training.Load
            mutate(Training.Load.Lag1 = lag(Training.Load, 1),
                   Training.Load.Lag2 = lag(Training.Load, 2),
                   Training.Load.Lag3 = lag(Training.Load, 3),
                   Training.Load.Lag4 = lag(Training.Load, 4),
                   Training.Load.Lag5 = lag(Training.Load, 5)) %>%
            ungroup()

# Remove the missing values (NAs)
turfData <-na.omit(turfData)

# Predict Morning.Soreness
trainingCtrl <- trainControl(method = "repeatedcv",
                             number = 5,
                             repeats = 10,
                             verboseIter = TRUE)
                     
target <- turfData$Morning.Soreness
predictors <- turfData %>%
              select(-Day, -Morning.Soreness, -Training.Load, -Field, -Athlete)

# Random Forest
#rfModel <- train(x = predictors,
#                 y = target,
#                 method = "rf",
#                 ntree = 1000,
#                 tuneLength = 3,
#                 metric = "RMSE",
#                 importance = TRUE,
#                 trControl = trainingCtrl)
#plot(rfModel)
#print(rfModel)
#plot(varImp(rfModel))

# CART
library(rpart.plot)
rpartModel <- train(x = predictors,
                 y = target,
                 method = "rpart",
                 tuneLength = 10,
                 metric = "RMSE",
                 trControl = trainingCtrl)
prp(rpartModel$finalModel)
print(rpartModel)
plot(varImp(rpartModel))

# Predict the values
turfData$RPART.Prediction <- predict(rpartModel)

# Plot the data
gg <- ggplot(turfData, aes(x = Day)) +
    geom_bar(aes(y = Training.Load), stat="identity", alpha = 0.3) +
    geom_line(aes(y = Morning.Soreness), color = "blue", alpha = 0.5) + 
    geom_line(aes(y = RPART.Prediction), color = "red") + 
    facet_wrap(~Athlete) +
    theme_bw()
gg


